@@ -1,8 +1,7 @@
 from .app import App, AppSync
-from .app_config import DEFAULT_CONFIG, AppConfig, AppConfigT
+from .app_config import AppConfig, AppConfigT
 
 __all__ = [
-    "DEFAULT_CONFIG",
     "App",
     "AppConfig",
     "AppConfigT",
